@@ -1,5 +1,5 @@
 package Convert::Z85;
-$Convert::Z85::VERSION = '0.004002';
+$Convert::Z85::VERSION = '1.001001';
 use Carp;
 use strict; use warnings FATAL => 'all';
 
@@ -36,7 +36,7 @@ sub encode_z85 {
   
   my $str;
   for my $val (@values) {
-    $str .= $chrs[ ( int($val / $_) ) % 85 ] for @multiples;
+    $str .= $chrs[ int($val / $_) % 85 ] for @multiples;
   }
   
   $str
@@ -114,10 +114,10 @@ specified to pad data with trailing zero bytes:
 
 Takes a Z85 text string and returns the original binary data.
 
-Throws a stack trace if invalid data is encountered.
+Dies (with a stack trace) if invalid data is encountered.
 
-Per the spec, removing padding is not performed automatically; the B<pad>
-option can be specified to remove trailing zero bytes:
+Padding (see L</encode_z85>) is not handled automatically; the B<pad> option
+can be specified to remove trailing zero bytes:
 
   my $bin = decode_z85($encoded, pad => 1);
 
